@@ -21,7 +21,7 @@ use C4::Creators::PDF;
 #    }
 
 sub _check_params {
-    my $exit_code = 0;
+    my $exit_code         = 0;
     my @valtmpl_id_params = (
         'layout_id',
         'barcode_type',
@@ -41,18 +41,17 @@ sub _check_params {
         'units',
         'start_label',
     );
-    if (scalar(@_) >1) {
+    if ( scalar(@_) > 1 ) {
         my %given_params = @_;
-        foreach my $key (keys %given_params) {
-            if (!(grep m/$key/, @valtmpl_id_params)) {
-                warn sprintf('(Multiple parameters) Unrecognized parameter type of "%s".', $key);
+        foreach my $key ( keys %given_params ) {
+            if ( !( grep m/$key/, @valtmpl_id_params ) ) {
+                warn sprintf( '(Multiple parameters) Unrecognized parameter type of "%s".', $key );
                 $exit_code = 1;
             }
         }
-    }
-    else {
-        if (!(grep m/$_/, @valtmpl_id_params)) {
-            warn sprintf('(Single parameter) Unrecognized parameter type of "%s".', $_);
+    } else {
+        if ( !( grep m/$_/, @valtmpl_id_params ) ) {
+            warn sprintf( '(Single parameter) Unrecognized parameter type of "%s".', $_ );
             $exit_code = 1;
         }
     }
@@ -60,10 +59,11 @@ sub _check_params {
 }
 
 use constant PRESET_FIELDS => [qw(title author isbn issn itemtype barcode itemcallnumber)];
+
 sub new {
     my $invocant = shift;
-    my $self = '';
-    if (_check_params(@_) eq 1) {
+    my $self     = '';
+    if ( _check_params(@_) eq 1 ) {
         return -1;
     }
     my $type = ref($invocant) || $invocant;
@@ -86,104 +86,104 @@ sub new {
             format_string => join( ', ', @{ PRESET_FIELDS() } ),
             @_,
         };
-    }
-    elsif (grep {$_ eq 'Patroncards'} @_) {
+    } elsif ( grep { $_ eq 'Patroncards' } @_ ) {
         $self = {
             layout_xml => '<opt>Default Layout</opt>',
             @_,
-        }
+        };
     }
-    bless ($self, $type);
+    bless( $self, $type );
     return $self;
 }
 
 sub retrieve {
     my $invocant = shift;
-    my %opts = @_;
-    my $type = ref($invocant) || $invocant;
-    my $query = "SELECT * FROM creator_layouts WHERE layout_id = ? AND creator = ?";
-    my $sth = C4::Context->dbh->prepare($query);
-    $sth->execute($opts{'layout_id'}, $opts{'creator'});
-    if ($sth->err) {
-        warn sprintf('Database returned the following error: %s', $sth->errstr);
+    my %opts     = @_;
+    my $type     = ref($invocant) || $invocant;
+    my $query    = "SELECT * FROM creator_layouts WHERE layout_id = ? AND creator = ?";
+    my $sth      = C4::Context->dbh->prepare($query);
+    $sth->execute( $opts{'layout_id'}, $opts{'creator'} );
+    if ( $sth->err ) {
+        warn sprintf( 'Database returned the following error: %s', $sth->errstr );
         return -1;
     }
     my $self = $sth->fetchrow_hashref;
-    bless ($self, $type);
+    bless( $self, $type );
     return $self;
 }
 
 sub delete {
-    my $self = {};
-    my %opts = ();
+    my $self      = {};
+    my %opts      = ();
     my $call_type = '';
-    my @params = ();
-    if (ref($_[0])) {
-        $self = shift;  # check to see if this is a method call
+    my @params    = ();
+    if ( ref( $_[0] ) ) {
+        $self      = shift;                          # check to see if this is a method call
         $call_type = 'C4::Labels::Layout->delete';
         push @params, $self->{'layout_id'}, $self->{'creator'};
-    }
-    else {
+    } else {
         my $class = shift;
-        %opts = @_;
+        %opts      = @_;
         $call_type = $class . '::delete';
         push @params, $opts{'layout_id'}, $opts{'creator'};
     }
-    if (scalar(@params) < 2) {   # If there is no layout id or creator type then we cannot delete it
-        warn sprintf('%s : Cannot delete layout as the profile ID is invalid or non-existent.', $call_type) if !$params[0];
-        warn sprintf('%s : Cannot delete layout as the creator type is invalid or non-existent.', $call_type) if !$params[1];
+    if ( scalar(@params) < 2 ) {    # If there is no layout id or creator type then we cannot delete it
+        warn sprintf( '%s : Cannot delete layout as the profile ID is invalid or non-existent.', $call_type )
+            if !$params[0];
+        warn sprintf( '%s : Cannot delete layout as the creator type is invalid or non-existent.', $call_type )
+            if !$params[1];
         return -1;
     }
     my $query = "DELETE FROM creator_layouts WHERE layout_id = ? AND creator = ?";
-    my $sth = C4::Context->dbh->prepare($query);
+    my $sth   = C4::Context->dbh->prepare($query);
     $sth->execute(@params);
-    if ($sth->err) {
-        warn sprintf('Database returned the following error on attempted DELETE: %s', $sth->errstr);
+    if ( $sth->err ) {
+        warn sprintf( 'Database returned the following error on attempted DELETE: %s', $sth->errstr );
         return -1;
     }
 }
 
 sub save {
     my $self = shift;
-    if ($self->{'layout_id'}) {        # if we have an id, the record exists and needs UPDATE
+    if ( $self->{'layout_id'} ) {    # if we have an id, the record exists and needs UPDATE
         my @params;
         my $query = "UPDATE creator_layouts SET ";
-        foreach my $key (keys %{$self}) {
-            next if ($key eq 'layout_id') || ($key eq 'creator');
-            push (@params, $self->{$key});
+        foreach my $key ( keys %{$self} ) {
+            next if ( $key eq 'layout_id' ) || ( $key eq 'creator' );
+            push( @params, $self->{$key} );
             $query .= "$key=?, ";
         }
-        $query = substr($query, 0, (length($query)-2));
+        $query = substr( $query, 0, ( length($query) - 2 ) );
         $query .= " WHERE layout_id=? AND creator = ?;";
-        push (@params, $self->{'layout_id'}, $self->{'creator'});
+        push( @params, $self->{'layout_id'}, $self->{'creator'} );
         my $sth = C4::Context->dbh->prepare($query);
+
         #local $sth->{TraceLevel} = "3";        # enable DBI trace and set level; outputs to STDERR
         $sth->execute(@params);
-        if ($sth->err) {
-            warn sprintf('Database returned the following error: %s', $sth->errstr);
+        if ( $sth->err ) {
+            warn sprintf( 'Database returned the following error: %s', $sth->errstr );
             return -1;
         }
         return $self->{'layout_id'};
-    }
-    else {                      # otherwise create a new record
+    } else {    # otherwise create a new record
         my @params;
-        delete $self->{layout_id}; # Could be an empty string
+        delete $self->{layout_id};    # Could be an empty string
         my $query = "INSERT INTO creator_layouts (";
-        foreach my $key (keys %{$self}) {
-            push (@params, $self->{$key});
+        foreach my $key ( keys %{$self} ) {
+            push( @params, $self->{$key} );
             $query .= "$key, ";
         }
-        $query = substr($query, 0, (length($query)-2));
+        $query = substr( $query, 0, ( length($query) - 2 ) );
         $query .= ") VALUES (";
-        for (my $i=1; $i<=(scalar keys %$self); $i++) {
+        for ( my $i = 1 ; $i <= ( scalar keys %$self ) ; $i++ ) {
             $query .= "?,";
         }
-        $query = substr($query, 0, (length($query)-1));
+        $query = substr( $query, 0, ( length($query) - 1 ) );
         $query .= ");";
         my $sth = C4::Context->dbh->prepare($query);
         $sth->execute(@params);
-        if ($sth->err) {
-            warn sprintf('Database returned the following error: %s', $sth->errstr);
+        if ( $sth->err ) {
+            warn sprintf( 'Database returned the following error: %s', $sth->errstr );
             return -1;
         }
         my $sth1 = C4::Context->dbh->prepare("SELECT MAX(layout_id) FROM creator_layouts;");
@@ -196,14 +196,13 @@ sub save {
 
 sub get_attr {
     my $self = shift;
-    if (_check_params(@_) eq 1) {
+    if ( _check_params(@_) eq 1 ) {
         return -1;
     }
     my ($attr) = @_;
-    if (exists($self->{$attr})) {
+    if ( exists( $self->{$attr} ) ) {
         return $self->{$attr};
-    }
-    else {
+    } else {
         return -1;
     }
     return;
@@ -211,26 +210,26 @@ sub get_attr {
 
 sub set_attr {
     my $self = shift;
-    if (_check_params(@_) eq 1) {
+    if ( _check_params(@_) eq 1 ) {
         return -1;
     }
     my %attrs = @_;
-    foreach my $attrib (keys(%attrs)) {
+    foreach my $attrib ( keys(%attrs) ) {
         $self->{$attrib} = $attrs{$attrib};
-    };
+    }
     return 0;
 }
 
 sub get_text_wrap_cols {
-    my $self = shift;
-    my %params = @_;
-    my $string = '';
-    my $strwidth = 0;
+    my $self      = shift;
+    my %params    = @_;
+    my $string    = '';
+    my $strwidth  = 0;
     my $col_count = 0;
-    my $textlimit = $params{'label_width'} - (( 3 * $params{'left_text_margin'} ) || 13.5 );
+    my $textlimit = $params{'label_width'} - ( ( 3 * $params{'left_text_margin'} ) || 13.5 );
 
-    while ($strwidth < $textlimit) {
-        $string .= '8'; # using '8' as filling char instead of '0'
+    while ( $strwidth < $textlimit ) {
+        $string .= '8';    # using '8' as filling char instead of '0'
         $col_count++;
         $strwidth = C4::Creators::PDF->StrWidth( $string, $self->{'font'}, $self->{'font_size'} );
     }
@@ -379,7 +378,7 @@ R       = Right
 =head2 delete()
 
     Invoking the delete method attempts to delete the layout from the database. The method returns 0 upon success and -1 upon failure. Errors are logged to the Apache log.
-    NOTE: This method may also be called as a function and passed a key/value pair simply deleteing that template from the database. See the example below.
+    NOTE: This method may also be called as a function and passed a key/value pair simply deleting that template from the database. See the example below.
 
     examples:
         C<my $exitstat = $layout->delete(); # to delete the record behind the $layout object>
