@@ -21,11 +21,11 @@ use Modern::Perl;
 
 use Carp;
 use Data::Dumper qw( Dumper );
-use Try::Tiny qw( catch try );
+use Try::Tiny    qw( catch try );
 
 use C4::Letters;
-use C4::Log qw( logaction );
-use C4::Stats qw( UpdateStats );
+use C4::Log      qw( logaction );
+use C4::Stats    qw( UpdateStats );
 use C4::Overdues qw(GetFine);
 use C4::Context;
 
@@ -45,6 +45,12 @@ Koha::Accounts - Module for managing payments and fees for patrons
 
 =cut
 
+=head2 new
+
+Missing POD for new.
+
+=cut
+
 sub new {
     my ( $class, $params ) = @_;
 
@@ -79,7 +85,7 @@ sub pay {
     my $note          = $params->{note} || q{};
     my $library_id    = $params->{library_id};
     my $lines         = $params->{lines};
-    my $type          = $params->{type} || 'PAYMENT';
+    my $type          = $params->{type}         || 'PAYMENT';
     my $payment_type  = $params->{payment_type} || undef;
     my $cash_register = $params->{cash_register};
     my $item_id       = $params->{item_id};
@@ -98,9 +104,9 @@ sub pay {
             Koha::Exceptions::Account::InvalidPaymentType->throw( error => 'Invalid payment type' );
         }
     }
-    my $manager_id = $userenv ? $userenv->{number} : undef;
-    my $interface = $params ? ( $params->{interface} || C4::Context->interface ) : C4::Context->interface;
-    my $payment = $self->payin_amount(
+    my $manager_id = $userenv ? $userenv->{number}                                 : undef;
+    my $interface  = $params  ? ( $params->{interface} || C4::Context->interface ) : C4::Context->interface;
+    my $payment    = $self->payin_amount(
         {
             interface     => $interface,
             type          => $type,
@@ -119,30 +125,28 @@ sub pay {
     # NOTE: Pay historically always applied as much credit as it could to all
     # existing outstanding debits, whether passed specific debits or otherwise.
     if ( $payment->amountoutstanding ) {
-        $payment =
-          $payment->apply(
-            { debits => [ $self->outstanding_debits->as_list ] } );
+        $payment = $payment->apply( { debits => [ $self->outstanding_debits->as_list ] } );
     }
 
-    my $patron = Koha::Patrons->find( $self->{patron_id} );
-    my @account_offsets = $payment->credit_offsets({ type => 'APPLY' })->as_list;
-    if ( C4::Context->preference('UseEmailReceipts') ) {
+    my $patron          = Koha::Patrons->find( $self->{patron_id} );
+    my @account_offsets = $payment->credit_offsets( { type => 'APPLY' } )->as_list;
+    if ( C4::Context->preference('AutomaticEmailReceipts') ) {
         if (
             my $letter = C4::Letters::GetPreparedLetter(
                 module                 => 'circulation',
                 letter_code            => uc("ACCOUNT_$type"),
                 message_transport_type => 'email',
-                lang    => $patron->lang,
-                tables => {
-                    borrowers       => $self->{patron_id},
-                    branches        => $library_id,
+                lang                   => $patron->lang,
+                tables                 => {
+                    borrowers => $self->{patron_id},
+                    branches  => $library_id,
                 },
                 substitute => {
-                    credit => $payment,
+                    credit  => $payment,
                     offsets => \@account_offsets,
                 },
-              )
-          )
+            )
+            )
         {
             C4::Letters::EnqueueLetter(
                 {
@@ -155,7 +159,7 @@ sub pay {
     }
 
     my $renew_outcomes = [];
-    for my $message ( @{$payment->object_messages} ) {
+    for my $message ( @{ $payment->object_messages } ) {
         push @{$renew_outcomes}, $message->payload;
     }
 
@@ -201,20 +205,18 @@ sub add_credit {
     my @mandatory = ( 'interface', 'amount' );
     for my $param (@mandatory) {
         unless ( defined( $params->{$param} ) ) {
-            Koha::Exceptions::MissingParameter->throw(
-                error => "The $param parameter is mandatory" );
+            Koha::Exceptions::MissingParameter->throw( error => "The $param parameter is mandatory" );
         }
     }
 
     # amount should always be passed as a positive value
     my $amount = $params->{amount} * -1;
     unless ( $amount < 0 ) {
-        Koha::Exceptions::Account::AmountNotPositive->throw(
-            error => 'Debit amount passed is not positive' );
+        Koha::Exceptions::Account::AmountNotPositive->throw( error => 'Debit amount passed is not positive' );
     }
 
     my $description   = $params->{description} // q{};
-    my $note          = $params->{note} // q{};
+    my $note          = $params->{note}        // q{};
     my $user_id       = $params->{user_id};
     my $interface     = $params->{interface};
     my $library_id    = $params->{library_id};
@@ -225,17 +227,17 @@ sub add_credit {
     my $issue_id      = $params->{issue_id};
 
     my $old_issue_id;
-    if ( $issue_id ) {
+    if ($issue_id) {
         my $issue = Koha::Checkouts->find($issue_id);
-        unless ( $issue ) {
+        unless ($issue) {
             my $old_issue = Koha::Old::Checkouts->find($issue_id);
-            $issue_id = undef;
+            $issue_id     = undef;
             $old_issue_id = $old_issue->id;
         }
     }
 
     Koha::Exceptions::Account::RegisterRequired->throw()
-      if ( C4::Context->preference("UseCashRegisters")
+        if ( C4::Context->preference("UseCashRegisters")
         && defined($payment_type)
         && ( $payment_type eq 'CASH' || $payment_type eq 'SIP00' )
         && !defined($cash_register) );
@@ -300,7 +302,7 @@ sub add_credit {
                         action  => "add_credit",
                         payload => {
                             type => lc($credit_type),
-                            line => $line->get_from_storage, #TODO Seems unneeded
+                            line => $line->get_from_storage,    #TODO Seems unneeded
                         }
                     }
                 );
@@ -328,12 +330,10 @@ sub add_credit {
                 }
             }
         );
-    }
-    catch {
+    } catch {
         if ( ref($_) eq 'Koha::Exceptions::Object::FKConstraint' ) {
             if ( $_->broken_fk eq 'credit_type_code' ) {
-                Koha::Exceptions::Account::UnrecognisedType->throw(
-                    error => 'Type of credit not recognised' );
+                Koha::Exceptions::Account::UnrecognisedType->throw( error => 'Type of credit not recognised' );
             }
         }
         $_->rethrow;
@@ -377,23 +377,21 @@ sub payin_amount {
     my @mandatory = ( 'interface', 'amount', 'type' );
     for my $param (@mandatory) {
         unless ( defined( $params->{$param} ) ) {
-            Koha::Exceptions::MissingParameter->throw(
-                error => "The $param parameter is mandatory" );
+            Koha::Exceptions::MissingParameter->throw( error => "The $param parameter is mandatory" );
         }
     }
 
     # Check for mandatory register
     Koha::Exceptions::Account::RegisterRequired->throw()
-      if ( C4::Context->preference("UseCashRegisters")
+        if ( C4::Context->preference("UseCashRegisters")
         && defined( $params->{payment_type} )
         && ( $params->{payment_type} eq 'CASH' || $params->{payment_type} eq 'SIP00' )
-        && !defined($params->{cash_register}) );
+        && !defined( $params->{cash_register} ) );
 
     # amount should always be passed as a positive value
     my $amount = $params->{amount};
     unless ( $amount > 0 ) {
-        Koha::Exceptions::Account::AmountNotPositive->throw(
-            error => 'Payin amount passed is not positive' );
+        Koha::Exceptions::Account::AmountNotPositive->throw( error => 'Payin amount passed is not positive' );
     }
 
     my $credit;
@@ -406,22 +404,14 @@ sub payin_amount {
 
             # Offset debts passed first
             if ( exists( $params->{debits} ) ) {
-                $credit = $credit->apply(
-                    {
-                        debits => $params->{debits}
-                    }
-                );
+                $credit = $credit->apply( { debits => $params->{debits} } );
             }
 
             # Offset against remaining balance if AutoReconcile
             if ( C4::Context->preference("AccountAutoReconcile")
                 && $credit->amountoutstanding != 0 )
             {
-                $credit = $credit->apply(
-                    {
-                        debits => [ $self->outstanding_debits->as_list ]
-                    }
-                );
+                $credit = $credit->apply( { debits => [ $self->outstanding_debits->as_list ] } );
             }
         }
     );
@@ -475,14 +465,13 @@ sub add_debit {
     my @mandatory = ( 'interface', 'type', 'amount' );
     for my $param (@mandatory) {
         unless ( defined( $params->{$param} ) ) {
-            Koha::Exceptions::MissingParameter->throw(
-                error => "The $param parameter is mandatory" );
+            Koha::Exceptions::MissingParameter->throw( error => "The $param parameter is mandatory" );
         }
     }
 
     # check for cash register if using cash
     Koha::Exceptions::Account::RegisterRequired->throw()
-      if ( C4::Context->preference("UseCashRegisters")
+        if ( C4::Context->preference("UseCashRegisters")
         && defined( $params->{transaction_type} )
         && ( $params->{transaction_type} eq 'CASH' || $params->{payment_type} eq 'SIP00' )
         && !defined( $params->{cash_register} ) );
@@ -490,12 +479,11 @@ sub add_debit {
     # amount should always be a positive value
     my $amount = $params->{amount};
     unless ( $amount > 0 ) {
-        Koha::Exceptions::Account::AmountNotPositive->throw(
-            error => 'Debit amount passed is not positive' );
+        Koha::Exceptions::Account::AmountNotPositive->throw( error => 'Debit amount passed is not positive' );
     }
 
     my $description      = $params->{description} // q{};
-    my $note             = $params->{note} // q{};
+    my $note             = $params->{note}        // q{};
     my $user_id          = $params->{user_id};
     my $interface        = $params->{interface};
     my $library_id       = $params->{library_id};
@@ -506,16 +494,15 @@ sub add_debit {
     my $issue_id         = $params->{issue_id};
 
     my $old_issue_id;
-    if ( $issue_id ) {
+    if ($issue_id) {
         my $issue = Koha::Checkouts->find($issue_id);
-        unless ( $issue ) {
+        unless ($issue) {
             my $old_issue = Koha::Old::Checkouts->find($issue_id);
-            $issue_id = undef;
+            $issue_id     = undef;
             $old_issue_id = $old_issue->id;
         }
     }
 
-
     my $line;
     my $schema = Koha::Database->new->schema;
     try {
@@ -587,14 +574,11 @@ sub add_debit {
                 }
             }
         );
-    }
-    catch {
+    } catch {
         if ( ref($_) eq 'Koha::Exceptions::Object::FKConstraint' ) {
             if ( $_->broken_fk eq 'debit_type_code' ) {
-                Koha::Exceptions::Account::UnrecognisedType->throw(
-                    error => 'Type of debit not recognised' );
-            }
-            else {
+                Koha::Exceptions::Account::UnrecognisedType->throw( error => 'Type of debit not recognised' );
+            } else {
                 $_->rethrow;
             }
         }
@@ -626,41 +610,38 @@ sub payout_amount {
     my ( $self, $params ) = @_;
 
     # Check for mandatory parameters
-    my @mandatory =
-      ( 'interface', 'staff_id', 'branch', 'payout_type', 'amount' );
+    my @mandatory = ( 'interface', 'staff_id', 'branch', 'payout_type', 'amount' );
     for my $param (@mandatory) {
         unless ( defined( $params->{$param} ) ) {
-            Koha::Exceptions::MissingParameter->throw(
-                error => "The $param parameter is mandatory" );
+            Koha::Exceptions::MissingParameter->throw( error => "The $param parameter is mandatory" );
         }
     }
 
     # Check for mandatory register
     Koha::Exceptions::Account::RegisterRequired->throw()
-      if ( C4::Context->preference("UseCashRegisters")
+        if ( C4::Context->preference("UseCashRegisters")
         && ( $params->{payout_type} eq 'CASH' || $params->{payout_type} eq 'SIP00' )
-        && !defined($params->{cash_register}) );
+        && !defined( $params->{cash_register} ) );
 
     # Amount should always be passed as a positive value
     my $amount = $params->{amount};
     unless ( $amount > 0 ) {
-        Koha::Exceptions::Account::AmountNotPositive->throw(
-            error => 'Payout amount passed is not positive' );
+        Koha::Exceptions::Account::AmountNotPositive->throw( error => 'Payout amount passed is not positive' );
     }
 
     # Amount should always be less than or equal to outstanding credit
     my $outstanding = 0;
     my $outstanding_credits =
-      exists( $params->{credits} )
-      ? $params->{credits}
-      : $self->outstanding_credits->as_list;
+        exists( $params->{credits} )
+        ? $params->{credits}
+        : $self->outstanding_credits->as_list;
     for my $credit ( @{$outstanding_credits} ) {
         $outstanding += $credit->amountoutstanding;
     }
     $outstanding = $outstanding * -1;
-    Koha::Exceptions::ParameterTooHigh->throw( error =>
-"Amount to payout ($amount) is higher than amountoutstanding ($outstanding)"
-    ) unless ( $outstanding >= $amount );
+    Koha::Exceptions::ParameterTooHigh->throw(
+        error => "Amount to payout ($amount) is higher than amountoutstanding ($outstanding)" )
+        unless ( $outstanding >= $amount );
 
     my $payout;
     my $schema = Koha::Database->new->schema;
@@ -764,12 +745,11 @@ Charges can be set as exempt from non-issue by editing the debit type in the Deb
 sub non_issues_charges {
     my ($self) = @_;
 
-    my @blocking_debit_types = Koha::Account::DebitTypes->search({ restricts_checkouts => 1 }, { columns => 'code' })->get_column('code');
+    my @blocking_debit_types =
+        Koha::Account::DebitTypes->search( { restricts_checkouts => 1 }, { columns => 'code' } )->get_column('code');
 
     return $self->lines->search(
-        {
-            debit_type_code => { -in => \@blocking_debit_types }
-        },
+        { debit_type_code => { -in => \@blocking_debit_types } },
     )->total_outstanding;
 }
 
@@ -791,7 +771,6 @@ sub lines {
     );
 }
 
-
 =head3 credits
 
   my $credits = $self->credits;
@@ -803,11 +782,7 @@ Return all credits for the user
 sub credits {
     my ($self) = @_;
 
-    return Koha::Account::Credits->search(
-        {
-            borrowernumber => $self->{patron_id}
-        }
-    );
+    return Koha::Account::Credits->search( { borrowernumber => $self->{patron_id} } );
 }
 
 =head3 debits
@@ -823,7 +798,7 @@ sub debits {
 
     return Koha::Account::Debits->search(
         {
-            borrowernumber   => $self->{patron_id},
+            borrowernumber => $self->{patron_id},
         }
     );
 }
@@ -844,8 +819,8 @@ sub reconcile_balance {
     my $outstanding_debits  = $self->outstanding_debits;
     my $outstanding_credits = $self->outstanding_credits;
 
-    while (     $outstanding_debits->total_outstanding > 0
-            and my $credit = $outstanding_credits->next )
+    while ( $outstanding_debits->total_outstanding > 0
+        and my $credit = $outstanding_credits->next )
     {
         # there's both outstanding debits and credits
         $credit->apply( { debits => [ $outstanding_debits->as_list ] } );    # applying credit, no special offset
