@@ -18,7 +18,7 @@ package Koha::BackgroundJob::BatchUpdateAuthority;
 use Modern::Perl;
 
 use C4::MarcModificationTemplates qw( ModifyRecordWithTemplate );
-use C4::AuthoritiesMarc qw( ModAuthority );
+use C4::AuthoritiesMarc           qw( ModAuthority );
 use Koha::BackgroundJobs;
 use Koha::MetadataRecord::Authority;
 use Koha::SearchEngine;
@@ -61,7 +61,7 @@ sub process {
 
     $self->start;
 
-    my $mmtid = $args->{mmtid};
+    my $mmtid      = $args->{mmtid};
     my @record_ids = @{ $args->{record_ids} };
 
     my $report = {
@@ -69,27 +69,28 @@ sub process {
         total_success => 0,
     };
     my @messages;
-    RECORD_IDS: for my $record_id ( sort { $a <=> $b } @record_ids ) {
+RECORD_IDS: for my $record_id ( sort { $a <=> $b } @record_ids ) {
         next unless $record_id;
+
         # Authorities
         my $authid = $record_id;
-        my $error = eval {
-            my $authority = Koha::MetadataRecord::Authority->get_from_authid( $authid );
-            my $record = $authority->record;
+        my $error  = eval {
+            my $authority = Koha::MetadataRecord::Authority->get_from_authid($authid);
+            my $record    = $authority->record;
             ModifyRecordWithTemplate( $mmtid, $record );
             ModAuthority( $authid, $record, $authority->authtypecode, { skip_record_index => 1 } );
         };
         if ( $error and $error != $authid or $@ ) {
             push @messages, {
-                type => 'error',
-                code => 'authority_not_modified',
+                type   => 'error',
+                code   => 'authority_not_modified',
                 authid => $authid,
-                error => ($@ ? "$@" : 0),
+                error  => ( $@ ? "$@" : 0 ),
             };
         } else {
             push @messages, {
-                type => 'success',
-                code => 'authority_modified',
+                type   => 'success',
+                code   => 'authority_modified',
                 authid => $authid,
             };
             $report->{total_success}++;
@@ -97,14 +98,14 @@ sub process {
         $self->step;
     }
 
-    my $indexer = Koha::SearchEngine::Indexer->new({ index => $Koha::SearchEngine::AUTHORITIES_INDEX });
+    my $indexer = Koha::SearchEngine::Indexer->new( { index => $Koha::SearchEngine::AUTHORITIES_INDEX } );
     $indexer->index_records( \@record_ids, "specialUpdate", "authorityserver" );
 
     my $data = $self->decoded_data;
     $data->{messages} = \@messages;
     $data->{report}   = $report;
 
-    $self->finish( $data );
+    $self->finish($data);
 
 }
 
@@ -115,20 +116,22 @@ Enqueue the new job
 =cut
 
 sub enqueue {
-    my ( $self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     # TODO Raise exception instead
     return unless exists $args->{mmtid};
     return unless exists $args->{record_ids};
 
-    my $mmtid = $args->{mmtid};
+    my $mmtid      = $args->{mmtid};
     my @record_ids = @{ $args->{record_ids} };
 
-    $self->SUPER::enqueue({
-        job_size  => scalar @record_ids,
-        job_args  => {mmtid => $mmtid, record_ids => \@record_ids,},
-        job_queue => 'long_tasks',
-    });
+    $self->SUPER::enqueue(
+        {
+            job_size  => scalar @record_ids,
+            job_args  => { mmtid => $mmtid, record_ids => \@record_ids, },
+            job_queue => 'long_tasks',
+        }
+    );
 }
 
 1;
