@@ -24,6 +24,7 @@ use Koha::SearchEngine::Indexer;
 
 use C4::Context;
 use C4::Biblio;
+use C4::Items;
 use C4::MarcModificationTemplates;
 
 use base 'Koha::BackgroundJob';
@@ -66,7 +67,7 @@ sub process {
 
     $self->start;
 
-    my $mmtid = $args->{mmtid};
+    my $mmtid      = $args->{mmtid};
     my @record_ids = @{ $args->{record_ids} };
 
     my $report = {
@@ -74,7 +75,7 @@ sub process {
         total_success => 0,
     };
     my @messages;
-    RECORD_IDS: for my $biblionumber ( sort { $a <=> $b } @record_ids ) {
+RECORD_IDS: for my $biblionumber ( sort { $a <=> $b } @record_ids ) {
 
         last if $self->get_from_storage->status eq 'cancelled';
 
@@ -85,23 +86,37 @@ sub process {
             my $biblio = Koha::Biblios->find($biblionumber);
             my $record = $biblio->metadata->record;
             C4::MarcModificationTemplates::ModifyRecordWithTemplate( $mmtid, $record );
-            my $frameworkcode = C4::Biblio::GetFrameworkCode( $biblionumber );
-            C4::Biblio::ModBiblio( $record, $biblionumber, $frameworkcode, {
-                overlay_context   => $args->{overlay_context},
-                skip_record_index => 1,
-            });
+            my $frameworkcode = C4::Biblio::GetFrameworkCode($biblionumber);
+
+            if ( marc_record_contains_item_data($record) ) {
+                my ( $can_add_item, $add_item_error_message ) = can_add_item_from_marc_record($record);
+                return $add_item_error_message unless $can_add_item;
+
+                my $biblioitemnumber = $biblio->biblioitem->biblioitemnumber;
+                C4::Items::AddItemFromMarc( $record, $biblionumber, { biblioitemnumber => $biblioitemnumber } );
+            }
+
+            C4::Biblio::ModBiblio(
+                $record,
+                $biblionumber,
+                $frameworkcode,
+                {
+                    overlay_context   => $args->{overlay_context},
+                    skip_record_index => 1,
+                }
+            );
         };
-        if ( $error and $error != 1 or $@ ) { # ModBiblio returns 1 if everything as gone well
+        if ( $error and $error != 1 or $@ ) {    # ModBiblio returns 1 if everything as gone well
             push @messages, {
-                type => 'error',
-                code => 'biblio_not_modified',
+                type         => 'error',
+                code         => 'biblio_not_modified',
                 biblionumber => $biblionumber,
-                error => ($@ ? "$@" : $error),
+                error        => ( $@ ? "$@" : $error ),
             };
         } else {
             push @messages, {
-                type => 'success',
-                code => 'biblio_modified',
+                type         => 'success',
+                code         => 'biblio_modified',
                 biblionumber => $biblionumber,
             };
             $report->{total_success}++;
@@ -110,14 +125,14 @@ sub process {
         $self->step;
     }
 
-    my $indexer = Koha::SearchEngine::Indexer->new({ index => $Koha::SearchEngine::BIBLIOS_INDEX });
+    my $indexer = Koha::SearchEngine::Indexer->new( { index => $Koha::SearchEngine::BIBLIOS_INDEX } );
     $indexer->index_records( \@record_ids, "specialUpdate", "biblioserver" );
 
     my $data = $self->decoded_data;
     $data->{messages} = \@messages;
-    $data->{report} = $report;
+    $data->{report}   = $report;
 
-    $self->finish( $data );
+    $self->finish($data);
 }
 
 =head3 enqueue
@@ -127,17 +142,19 @@ Enqueue the new job
 =cut
 
 sub enqueue {
-    my ( $self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     # TODO Raise exception instead
     return unless exists $args->{mmtid};
     return unless exists $args->{record_ids};
 
-    $self->SUPER::enqueue({
-        job_size  => scalar @{$args->{record_ids}},
-        job_args  => $args,
-        job_queue => 'long_tasks',
-    });
+    $self->SUPER::enqueue(
+        {
+            job_size  => scalar @{ $args->{record_ids} },
+            job_args  => $args,
+            job_queue => 'long_tasks',
+        }
+    );
 }
 
 =head3 additional_report
@@ -162,4 +179,62 @@ sub additional_report {
     };
 }
 
+=head3 marc_record_contains_item_data
+
+Verify if MARC record contains item data
+
+=cut
+
+sub marc_record_contains_item_data {
+    my ($record) = @_;
+
+    my $itemfield   = C4::Context->preference('marcflavour') eq 'UNIMARC' ? '995' : '952';
+    my @item_fields = $record->field($itemfield);
+    return scalar @item_fields;
+}
+
+=head3 can_add_item_from_marc_record
+
+Checks if adding an item from MARC can be done by checking mandatory fields
+
+=cut
+
+sub can_add_item_from_marc_record {
+    my ($record) = @_;
+
+    # Check that holdingbranch is set
+    my $holdingbranch_mss = Koha::MarcSubfieldStructures->find(
+        {
+            frameworkcode => '',
+            kohafield     => 'items.holdingbranch',
+        }
+    );
+    my @holdingbranch_exists =
+        grep { $_->subfield( $holdingbranch_mss->tagsubfield ) } $record->field( $holdingbranch_mss->tagfield );
+    return ( 0, "No holdingbranch subfield found" ) unless ( scalar @holdingbranch_exists );
+
+    # Check that homebranch is set
+    my $homebranch_mss = Koha::MarcSubfieldStructures->find(
+        {
+            frameworkcode => '',
+            kohafield     => 'items.homebranch',
+        }
+    );
+    my @homebranch_exists =
+        grep { $_->subfield( $homebranch_mss->tagsubfield ) } $record->field( $homebranch_mss->tagfield );
+    return ( 0, "No homebranch subfield found" ) unless ( scalar @homebranch_exists );
+
+    # Check that itemtype is set
+    my $item_mss = Koha::MarcSubfieldStructures->find(
+        {
+            frameworkcode => '',
+            kohafield     => C4::Context->preference('item-level_itypes') ? 'items.itype' : 'biblioitems.itemtype',
+        }
+    );
+    my @itemtype_exists = grep { $_->subfield( $item_mss->tagsubfield ) } $record->field( $item_mss->tagfield );
+    return ( 0, "No itemtype subfield found" ) unless ( scalar @itemtype_exists );
+
+    return 1;
+}
+
 1;
