@@ -17,7 +17,6 @@ package Koha::BiblioFrameworks;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::BiblioFramework;
@@ -42,6 +41,12 @@ sub _type {
     return 'BiblioFramework';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::BiblioFramework';
 }
