@@ -41,6 +41,12 @@ sub _type {
     return 'ErmEholdingsResource';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::ERM::EHoldings::Resource';
 }
