@@ -39,6 +39,12 @@ sub _type {
     return 'BorrowerAttributeType';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::Patron::Attribute::Type';
 }
