@@ -17,7 +17,6 @@ package Koha::Patron::Images;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::Patron::Image;
@@ -42,6 +41,12 @@ sub _type {
     return 'Patronimage';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::Patron::Image';
 }
