@@ -46,8 +46,7 @@ sub list {
     return try {
         my $libraries = $c->objects->search( Koha::Libraries->new );
         return $c->render( status => 200, openapi => $libraries );
-    }
-    catch {
+    } catch {
         $c->unhandled_exception($_);
     };
 }
@@ -94,8 +93,7 @@ sub add {
             status  => 201,
             openapi => $c->objects->to_api($library),
         );
-    }
-    catch {
+    } catch {
         if ( blessed $_ && $_->isa('Koha::Exceptions::Object::DuplicateID') ) {
             return $c->render(
                 status  => 409,
@@ -123,14 +121,13 @@ sub update {
 
     return try {
         my $params = $c->req->json;
-        $library->set_from_api( $params );
+        $library->set_from_api($params);
         $library->store();
         return $c->render(
             status  => 200,
             openapi => $c->objects->to_api($library),
         );
-    }
-    catch {
+    } catch {
         $c->unhandled_exception($_);
     };
 }
@@ -145,7 +142,7 @@ sub delete {
 
     my $c = shift->openapi->valid_input or return;
 
-    my $library = Koha::Libraries->find( $c->param( 'library_id' ) );
+    my $library = Koha::Libraries->find( $c->param('library_id') );
 
     return $c->render_resource_not_found("Library")
         unless $library;
@@ -153,8 +150,7 @@ sub delete {
     return try {
         $library->delete;
         return $c->render_resource_deleted;
-    }
-    catch {
+    } catch {
         $c->unhandled_exception($_);
     };
 }
