@@ -25,8 +25,6 @@ use Scalar::Util qw(blessed);
 use Try::Tiny;
 use Koha::Token;
 use URI::Escape qw(uri_escape_utf8);
-use Koha::Session;
-use Koha::Auth::Identity::Referer;
 
 =head1 NAME
 
@@ -62,24 +60,17 @@ sub login {
         }
     } else {
         $redirect_url = C4::Context->preference('staffClientBaseURL') . '/api/v1/oauth/login/';
-        $uri = '/cgi-bin/koha/mainpage.pl';
-    }
-
-    my $current_session;
-    my $current_session_cookie = $c->req->cookie('CGISESSID');
-    if ($current_session_cookie) {
-        my $current_session_id = $current_session_cookie->value;
-        $current_session = Koha::Session->get_session( { sessionID => $current_session_id } );
+        $uri          = '/cgi-bin/koha/mainpage.pl';
     }
 
     unless ( $provider_config && $provider_config->{authorize_url} ) {
         my $error = "No configuration found for your provider";
-        return $c->redirect_to($uri."?auth_error=$error");
+        return $c->redirect_to( $uri . "?auth_error=$error" );
     }
 
     unless ( $provider_config->{authorize_url} =~ /response_type=code/ ) {
-        my $authorize_url = Mojo::URL->new($provider_config->{authorize_url});
-        $authorize_url->query->append(response_type => 'code');
+        my $authorize_url = Mojo::URL->new( $provider_config->{authorize_url} );
+        $authorize_url->query->append( response_type => 'code' );
         $provider_config->{authorize_url} = $authorize_url->to_string;
     }
 
@@ -89,6 +80,7 @@ sub login {
     my $state;
 
     if ($is_callback) {
+
         # callback, check CSRF token
         unless (
             Koha::Token->new->check_csrf(
@@ -97,32 +89,29 @@ sub login {
                     token      => $c->param('state'),
                 }
             )
-          )
+            )
         {
             my $error = "wrong_csrf_token";
             return $c->redirect_to( $uri . "?auth_error=$error" );
         }
-    }
-    else {
+    } else {
+
         # initial request, generate CSRF token
         $state = Koha::Token->new->generate_csrf( { session_id => $c->req->cookie('CGISESSID')->value } );
-
-        Koha::Auth::Identity::Referer->store_referer(
-            {
-                referer   => $c->req->headers->referer,
-                interface => $interface,
-                session   => $current_session,
-            }
-        );
     }
 
-    return $c->oauth2->get_token_p( $provider => { ( !$is_callback ? ( state => $state ) : () ), redirect_uri => $redirect_url . $provider . "/" . $interface } )->then(
+    return $c->oauth2->get_token_p(
+        $provider => {
+            ( !$is_callback ? ( state => $state ) : () ), redirect_uri => $redirect_url . $provider . "/" . $interface
+        }
+    )->then(
         sub {
             return unless my $response = shift;
 
             try {
                 my ( $patron, $mapped_data, $domain ) = Koha::Auth::Client::OAuth->new->get_user(
-                    {   provider  => $provider,
+                    {
+                        provider  => $provider,
                         data      => $response,
                         interface => $interface,
                         config    => $c->oauth2->providers->{$provider}
@@ -139,22 +128,16 @@ sub login {
                     );
                 }
 
-                my $session_id = $c->auth->session({ patron => $patron, interface => $interface, provider => $provider });
+                my $session_id =
+                    $c->auth->session( { patron => $patron, interface => $interface, provider => $provider } );
 
                 $c->cookie( CGISESSID => $session_id, { path => "/" } );
 
-                my $target_uri = Koha::Auth::Identity::Referer->get_referer(
-                    {
-                        session => $current_session,
-                    }
-                );
-                if ($target_uri) {
-                    $uri = $target_uri;
-                }
                 $c->redirect_to($uri);
             } catch {
                 my $error = $_;
                 $c->app->log->error($error);
+
                 # TODO: Review behavior
                 if ( blessed $error ) {
                     if ( $error->isa('Koha::Exceptions::Auth::Unauthorized') ) {
@@ -167,7 +150,7 @@ sub login {
 
                 $error = uri_escape_utf8($error);
 
-                $c->redirect_to($uri."?auth_error=$error");
+                $c->redirect_to( $uri . "?auth_error=$error" );
             };
         }
     )->catch(
@@ -175,7 +158,7 @@ sub login {
             my $error = shift;
             $c->app->log->error($error);
             $error = uri_escape_utf8($error);
-            $c->redirect_to($uri."?auth_error=$error");
+            $c->redirect_to( $uri . "?auth_error=$error" );
         }
     )->wait;
 }
