@@ -121,9 +121,8 @@ sub add {
                             module      => 'members',
                             letter_code => 'WELCOME',
                             branchcode  => $patron->branchcode,
-                            ,
-                            lang   => $patron->lang || 'default',
-                            tables => {
+                            lang        => $patron->lang || 'default',
+                            tables      => {
                                 'branches'  => $patron->branchcode,
                                 'borrowers' => $patron->borrowernumber,
                             },
@@ -139,7 +138,9 @@ sub add {
                                     message_transport_type => 'email'
                                 }
                             );
-                            SendQueuedMessages( { message_id => $message_id } );
+
+                            # Don't send a message if we didn't generate one for some reason
+                            SendQueuedMessages( { message_id => $message_id } ) if $message_id;
                         }
                     }
                 }
@@ -183,9 +184,12 @@ sub add {
                     openapi => { error => "Given " . $to_api_mapping->{ $_->broken_fk } . " does not exist" }
                 );
             } elsif ( $_->isa('Koha::Exceptions::BadParameter') ) {
+                my $parameter = $to_api_mapping->{ $_->parameter } || $_->parameter;
+                my $error =
+                    $parameter ? "Given " . $to_api_mapping->{ $_->parameter } . " does not exist" : $_->full_message;
                 return $c->render(
                     status  => 400,
-                    openapi => { error => "Given " . $to_api_mapping->{ $_->parameter } . " does not exist" }
+                    openapi => { error => $error }
                 );
             } elsif ( $_->isa('Koha::Exceptions::Patron::MissingMandatoryExtendedAttribute') ) {
                 return $c->render(
