@@ -17,7 +17,6 @@ package Koha::SearchField;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use base qw(Koha::Object);
@@ -32,9 +31,15 @@ Koha::SearchField - Koha SearchField Object class
 
 =cut
 
+=head2 add_to_search_marc_maps
+
+Missing POD for add_to_search_marc_maps.
+
+=cut
+
 sub add_to_search_marc_maps {
     my ( $self, $search_field, $params ) = @_;
-    return $self->_result()->add_to_search_marc_maps($search_field->_result, $params);
+    return $self->_result()->add_to_search_marc_maps( $search_field->_result, $params );
 }
 
 =head3 search_marc_maps
@@ -44,11 +49,11 @@ my $search_marc_maps = $search_field->search_marc_maps;
 =cut
 
 sub search_marc_maps {
-    my ( $self ) = @_;
+    my ($self) = @_;
 
     my $marc_type = lc C4::Context->preference('marcflavour');
 
-    my $schema = Koha::Database->new->schema;
+    my $schema          = Koha::Database->new->schema;
     my $marc_map_fields = $schema->resultset('SearchMarcToField')->search(
         {
             'me.search_field_id'        => $self->id,
@@ -60,7 +65,7 @@ sub search_marc_maps {
                 'search_marc_map.marc_type',
                 'search_marc_map.marc_field'
             ],
-            as => [ 'index_name', 'marc_type', 'marc_field' ],
+            as   => [ 'index_name', 'marc_type', 'marc_field' ],
             join => 'search_marc_map'
         }
     );
@@ -87,13 +92,9 @@ my $is_mapped_biblios = $search_field->is_mapped_biblios
 =cut
 
 sub is_mapped_biblios {
-    my ( $self ) = @_;
+    my ($self) = @_;
 
-    return $self->search_marc_maps->search(
-        {
-            index_name => 'biblios'
-        }
-    )->count ? 1 : 0;
+    return $self->search_marc_maps->search( { index_name => 'biblios' } )->count ? 1 : 0;
 }
 
 =head3 type
