@@ -32,18 +32,20 @@ and add possibility to indicate a reason for cancellation
 use Modern::Perl;
 
 use CGI;
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_html_with_http_headers );
-use C4::Log qw(logaction);
+use C4::Log    qw(logaction);
 use Koha::Acquisition::Baskets;
 
 my $input = CGI->new;
-my ($template, $loggedinuser, $cookie, $flags) = get_template_and_user( {
-    template_name   => 'acqui/cancelorder.tt',
-    query           => $input,
-    type            => 'intranet',
-    flagsrequired   => { 'acquisition' => 'order_manage' },
-} );
+my ( $template, $loggedinuser, $cookie, $flags ) = get_template_and_user(
+    {
+        template_name => 'acqui/cancelorder.tt',
+        query         => $input,
+        type          => 'intranet',
+        flagsrequired => { 'acquisition' => 'order_manage' },
+    }
+);
 
 my $op            = $input->param('op') || q{};
 my $ordernumber   = $input->param('ordernumber');
@@ -54,17 +56,17 @@ my $basket        = Koha::Acquisition::Baskets->find( { basketno => $basketno },
 my $referrer      = $input->param('referrer') || $input->referer;
 my $delete_biblio = $input->param('del_biblio') ? 1 : 0;
 
-if( $op eq "cud-confirmcancel" ) {
+if ( $op eq "cud-confirmcancel" ) {
     my $reason = $input->param('reason');
     my @messages;
-    if( !$order ) {
-        push @messages, Koha::Object::Message->new({ message => 'error_order_not_found', type => 'error' });
+    if ( !$order ) {
+        push @messages, Koha::Object::Message->new( { message => 'error_order_not_found', type => 'error' } );
         $template->param( error_order_not_found => 1 );
-    } elsif( $order->datecancellationprinted ) {
-        push @messages, Koha::Object::Message->new({ message => 'error_order_already_cancelled', type => 'error' });
+    } elsif ( $order->datecancellationprinted ) {
+        push @messages, Koha::Object::Message->new( { message => 'error_order_already_cancelled', type => 'error' } );
         $template->param( error_order_already_cancelled => 1 );
     } else {
-        $order->cancel({ reason => $reason, delete_biblio => $delete_biblio });
+        $order->cancel( { reason => $reason, delete_biblio => $delete_biblio } );
         @messages = @{ $order->object_messages };
     }
 
@@ -74,21 +76,22 @@ if( $op eq "cud-confirmcancel" ) {
         $template->param( error_delbiblio => 1 )
             if $messages[0]->message eq 'error_delbiblio';
     } else {
+
         # Log the cancellation of the order
-        if (C4::Context->preference("AcquisitionLog")) {
-            logaction('ACQUISITIONS', 'CANCEL_ORDER', $ordernumber);
+        if ( C4::Context->preference("AcquisitionLog") ) {
+            logaction( 'ACQUISITIONS', 'CANCEL_ORDER', $ordernumber );
         }
-        $template->param(success_cancelorder => 1);
+        $template->param( success_cancelorder => 1 );
     }
-    $template->param(confirmcancel => 1);
+    $template->param( confirmcancel => 1 );
 }
 
 $template->param(
-    ordernumber => $ordernumber,
+    ordernumber  => $ordernumber,
     biblionumber => $biblionumber,
-    basket => $basket,
-    referrer => $referrer,
-    del_biblio => $delete_biblio,
+    basket       => $basket,
+    referrer     => $referrer,
+    del_biblio   => $delete_biblio,
 );
 
 output_html_with_http_headers $input, $cookie, $template->output;
