@@ -19,11 +19,11 @@
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
+use CGI          qw ( -utf8 );
 use Scalar::Util qw( blessed );
-use Try::Tiny qw( catch try );
+use Try::Tiny    qw( catch try );
 
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_html_with_http_headers );
 
 use Koha::Libraries;
@@ -33,10 +33,11 @@ my $input = CGI->new;
 my $op    = $input->param('op') || 'list';
 
 my ( $template, $borrowernumber, $cookie ) = get_template_and_user(
-    {   template_name   => "admin/smtp_servers.tt",
-        query           => $input,
-        type            => "intranet",
-        flagsrequired   => { parameters => 'manage_smtp_servers' },
+    {
+        template_name => "admin/smtp_servers.tt",
+        query         => $input,
+        type          => "intranet",
+        flagsrequired => { parameters => 'manage_smtp_servers' },
     }
 );
 
@@ -48,13 +49,13 @@ if ( $op eq 'cud-add' ) {
 
     my $name       = $input->param('smtp_name');
     my $host       = $input->param('smtp_host');
-    my $port       = $input->param('smtp_port') || 25;
+    my $port       = $input->param('smtp_port')    || 25;
     my $timeout    = $input->param('smtp_timeout') || 120;
     my $ssl_mode   = $input->param('smtp_ssl_mode');
     my $user_name  = $input->param('smtp_user_name') || undef;
-    my $password   = $input->param('smtp_password') || undef;
+    my $password   = $input->param('smtp_password')  || undef;
     my $debug      = ( scalar $input->param('smtp_debug_mode') ) ? 1 : 0;
-    my $is_default = ( scalar $input->param('smtp_default') ) ? 1 : 0;
+    my $is_default = ( scalar $input->param('smtp_default') )    ? 1 : 0;
 
     try {
 
@@ -73,44 +74,40 @@ if ( $op eq 'cud-add' ) {
         )->store;
 
         push @messages, { type => 'message', code => 'success_on_insert' };
-    }
-    catch {
+    } catch {
         if ( blessed $_ and $_->isa('Koha::Exceptions::Object::DuplicateID') ) {
             push @messages,
-              {
+                {
                 type   => 'alert',
                 code   => 'error_on_insert',
                 reason => 'duplicate_id'
-              };
+                };
         }
     };
 
     # list servers after adding
     $op = 'list';
-}
-elsif ( $op eq 'edit_form' ) {
+} elsif ( $op eq 'edit_form' ) {
     my $smtp_server_id = $input->param('smtp_server_id');
     my $smtp_server;
 
     $smtp_server = Koha::SMTP::Servers->find($smtp_server_id)
         unless !$smtp_server_id;
 
-    if ( $smtp_server ) {
+    if ($smtp_server) {
         $template->param(
-            smtp_server => $smtp_server,
+            smtp_server    => $smtp_server,
             default_config => $smtp_servers->get_default,
         );
-    }
-    else {
+    } else {
         push @messages,
             {
-                type   => 'alert',
-                code   => 'error_on_edit',
-                reason => 'invalid_id'
+            type   => 'alert',
+            code   => 'error_on_edit',
+            reason => 'invalid_id'
             };
     }
-}
-elsif ( $op eq 'cud-edit_save' ) {
+} elsif ( $op eq 'cud-edit_save' ) {
 
     my $smtp_server_id = $input->param('smtp_server_id');
     my $smtp_server;
@@ -118,23 +115,23 @@ elsif ( $op eq 'cud-edit_save' ) {
     $smtp_server = Koha::SMTP::Servers->find($smtp_server_id)
         unless !$smtp_server_id;
 
-    if ( $smtp_server ) {
+    if ($smtp_server) {
 
         my $name       = $input->param('smtp_name');
         my $host       = $input->param('smtp_host');
-        my $port       = $input->param('smtp_port') || 25;
+        my $port       = $input->param('smtp_port')    || 25;
         my $timeout    = $input->param('smtp_timeout') || 120;
         my $ssl_mode   = $input->param('smtp_ssl_mode');
         my $user_name  = $input->param('smtp_user_name') || undef;
-        my $password   = $input->param('smtp_password') || undef;
+        my $password   = $input->param('smtp_password')  || undef;
         my $debug      = ( scalar $input->param('smtp_debug_mode') ) ? 1 : 0;
-        my $is_default = ( scalar $input->param('smtp_default') ) ? 1 : 0;
+        my $is_default = ( scalar $input->param('smtp_default') )    ? 1 : 0;
 
         try {
 
-            $smtp_server->password( $password )
+            $smtp_server->password($password)
                 if defined $password and $password ne '****'
-                    or not defined $password;
+                or not defined $password;
 
             $smtp_server->set(
                 {
@@ -150,28 +147,26 @@ elsif ( $op eq 'cud-edit_save' ) {
             )->store;
 
             push @messages,
-            {
+                {
                 type => 'message',
                 code => 'success_on_update'
-            };
-        }
-        catch {
+                };
+        } catch {
             push @messages,
-            {
-                type   => 'alert',
-                code   => 'error_on_update'
-            };
+                {
+                type => 'alert',
+                code => 'error_on_update'
+                };
         };
 
         # list servers after adding
         $op = 'list';
-    }
-    else {
+    } else {
         push @messages,
             {
-                type   => 'alert',
-                code   => 'error_on_update',
-                reason => 'invalid_id'
+            type   => 'alert',
+            code   => 'error_on_update',
+            reason => 'invalid_id'
             };
     }
 }
