@@ -21,34 +21,36 @@
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
-use C4::Auth qw( get_template_and_user );
+use CGI             qw ( -utf8 );
+use C4::Auth        qw( get_template_and_user );
 use C4::Circulation qw( barcodedecode );
-use C4::Output qw( output_html_with_http_headers );
+use C4::Output      qw( output_html_with_http_headers );
 
 use Koha::Biblios;
 use Koha::Items;
 
 my $query = CGI->new;
 
-my ($template, $loggedinuser, $cookie) = get_template_and_user(
+my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "cataloguing/moveitem.tt",
-        query           => $query,
-        type            => "intranet",
-        flagsrequired   => { editcatalogue => 'edit_items' },
+        template_name => "cataloguing/moveitem.tt",
+        query         => $query,
+        type          => "intranet",
+        flagsrequired => { editcatalogue => 'edit_items' },
     }
 );
 
 my $op = $query->param('op') || q{};
+
 # The biblio to move the item to
 my $biblionumber = $query->param('biblionumber');
+
 # The barcode of the item to move
 my $barcode = barcodedecode( scalar $query->param('barcode') );
 
-my $biblio = Koha::Biblios->find( $biblionumber );
-$template->param(biblio => $biblio);
-$template->param(biblionumber => $biblionumber);
+my $biblio = Koha::Biblios->find($biblionumber);
+$template->param( biblio       => $biblio );
+$template->param( biblionumber => $biblionumber );
 
 # If we already have the barcode of the item to move and the biblionumber to move the item to
 if ( $op eq 'cud-moveitem' && $barcode && $biblionumber ) {
@@ -60,24 +62,22 @@ if ( $op eq 'cud-moveitem' && $barcode && $biblionumber ) {
 
         $itemnumber = $item->itemnumber;
         my $frombiblionumber = $item->biblionumber;
-        my $to_biblio = Koha::Biblios->find($biblionumber);
+        my $to_biblio        = Koha::Biblios->find($biblionumber);
 
         my $moveresult = $item->move_to_biblio($to_biblio);
         if ($moveresult) {
             $template->param(
-                success => 1,
+                success     => 1,
                 from_biblio => Koha::Biblios->find($frombiblionumber),
             );
-        }
-        else {
+        } else {
             $template->param(
                 error          => 1,
                 errornonewitem => 1
             );
         }
 
-    }
-    else {
+    } else {
         $template->param(
             error       => 1,
             errornoitem => 1
@@ -88,8 +88,7 @@ if ( $op eq 'cud-moveitem' && $barcode && $biblionumber ) {
         itemnumber => $itemnumber,
     );
 
-}
-else {
+} else {
     $template->param( missingparameter => 1 );
     if ( !$barcode )      { $template->param( missingbarcode      => 1 ); }
     if ( !$biblionumber ) { $template->param( missingbiblionumber => 1 ); }
