@@ -42,8 +42,8 @@ use C4::Members;
 use C4::Output   qw( output_html_with_http_headers );
 use C4::Reserves qw( ModReserve ModReserveAffect CheckReserves );
 use C4::RotatingCollections;
-use C4::Log qw( logaction );
 use Koha::AuthorisedValues;
+use Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue;
 use Koha::BiblioFrameworks;
 use Koha::Calendar;
 use Koha::Checkouts;
@@ -159,32 +159,6 @@ if ( $query->param('reserve_id') && $op eq 'cud-affect_reserve' ) {
             $transfer->transit;
         }
     }
-} else {
-    my $message    = "return an element that is reserved";
-    my @message    = ("return an element that is reserved");
-    my $user       = C4::Context->userenv->{number};
-    my $branchcode = C4::Context->userenv->{branch};
-    my $barcode    = $query->param('barcode');
-
-    my $infos = (
-        {
-            message => \@message,
-
-            #'card number' => $cardnumber,
-            barcode    => $barcode,
-            manager_id => $user,
-            branchcode => $branchcode,
-        }
-    );
-
-    my $json_infos = JSON->new->utf8->pretty->encode($infos);
-    $json_infos =~ s/"/'/g;
-
-    logaction(
-        "CIRCULATION", "RETURN",
-        $session,
-        $json_infos,
-    ) if C4::Context->preference("ReturnLog");
 }
 
 if ( $query->param('recall_id') && $op eq 'cud-affect_recall' ) {
@@ -257,6 +231,14 @@ if ( $op eq 'cud-dotransfer' ) {
     $transfer->transit;
 }
 
+if ( $op eq 'cud-ignore_reserve' ) {
+    my $ignored_item = $query->param('ignoreitem');
+    my $item         = Koha::Items->find($ignored_item);
+    Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue->new->enqueue( { biblio_ids => [ $item->biblionumber ] } )
+        if C4::Context->preference('RealTimeHoldsQueue');
+
+}
+
 if ( $transit && $op eq 'cud-transfer' ) {
     my $transfer = Koha::Item::Transfers->find($transit);
     if ($canceltransfer) {
@@ -379,8 +361,13 @@ if ( $barcode && ( $op eq 'cud-checkin' || $op eq 'cud-affect_reserve' ) ) {
     }
 
     # do the return
-    ( $returned, $messages, $issue, $borrower ) = AddReturn( $barcode, $userenv_branch, $exemptfine, $return_date )
-        unless ( $needs_confirm || $bundle_confirm );
+    unless ( $needs_confirm || $bundle_confirm ) {
+        ( $returned, $messages, $issue, $borrower ) = AddReturn( $barcode, $userenv_branch, $exemptfine, $return_date );
+
+        # Rebuild the queue only after handling confirmations
+        Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue->new->enqueue( { biblio_ids => [ $item->biblionumber ] } )
+            if $returned && C4::Context->preference('RealTimeHoldsQueue');
+    }
 
     if ($returned) {
         my $date_due_dt = dt_from_string( $issue->date_due, 'sql' );
