@@ -1,14 +1,16 @@
 use Modern::Perl;
 
 return {
-    bug_number => "28774",
+    bug_number  => "28774",
     description => "Delete blank rental discounts",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
-        $dbh->do(q{
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
+        $dbh->do(
+            q{
             DELETE FROM circulation_rules
             WHERE rule_name = 'rentaldiscount' AND rule_value=''
-        });
+        }
+        );
     },
-}
+    }
