@@ -1,14 +1,16 @@
 use Modern::Perl;
 
 return {
-    bug_number => "29386",
+    bug_number  => "29386",
     description => "Extend background_jobs.data to LONGTEXT",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
-        $dbh->do(q|
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
+        $dbh->do(
+            q|
             ALTER TABLE background_jobs
             CHANGE COLUMN `data` `data` LONGTEXT DEFAULT NULL
-        |);
+        |
+        );
     },
-}
+    }
