@@ -44,10 +44,10 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    ( 3, 'manage_search_filters', 'Manage custom search filters'),
    ( 3, 'manage_identity_providers', 'Manage identity providers'),
    ( 3, 'manage_record_sources', 'Manage record sources'),
+   ( 4, 'api_validate_password', 'Validate patron passwords using the API'),
    ( 4, 'delete_borrowers', 'Delete patrons'),
    ( 4, 'edit_borrowers', 'Add, modify and view patron information'),
    ( 4, 'list_borrowers', 'Search, list and view patrons'),
-   ( 4, 'merge_borrowers', 'Merge patrons'),
    ( 4, 'send_messages_to_borrowers', 'Send messages to patrons'),
    ( 4, 'view_borrower_infos_from_any_libraries', 'View patron infos from any libraries'),
    ( 6, 'place_holds', 'Place holds for patrons'),
@@ -72,6 +72,7 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    (10, 'manual_credit', 'Add manual credits to a patron account'),
    (10, 'manual_invoice', 'Add manual invoices to a patron account'),
    (10, 'remaining_permissions', 'Remaining permissions for managing fines and fees'),
+   (10, 'edit_accountline_notes', 'Edit accountline notes'),
    (11, 'currencies_manage', 'Manage currencies and exchange rates'),
    (11, 'vendors_manage', 'Manage vendors'),
    (11, 'contracts_manage', 'Manage contracts'),
