@@ -1,9 +1,9 @@
 /* global __ */
 
-$(document).ready(function() {
+$(document).ready(function () {
     var checkboxes = $(".del-checkbox");
     var checkedcheckboxes = 0;
-    checkboxes.on("change", function() {
+    checkboxes.on("change", function () {
         if ($(".del-checkbox:checked").length > 0) {
             checkedcheckboxes = 1;
             $("#delete-alerts").removeClass("disabled");
@@ -22,39 +22,39 @@ $(document).ready(function() {
     });
 
     var soundfield = $("#sound");
-    var playsound = $('#play-sound');
+    var playsound = $("#play-sound");
 
-    soundfield.on("change", function() {
+    soundfield.on("change", function () {
         enablePlayButton($(this).val(), playsound);
     });
 
     $(".edit-alert").hide();
     $("#new-alert-form").hide();
 
-    $("#newalert").on("click", function(e) {
+    $("#newalert").on("click", function (e) {
         e.preventDefault();
-        $("#new-alert-form").show(0, function() {
+        $("#new-alert-form").show(0, function () {
             $("#selector").focus();
         });
         $("#toolbar, #delete-alert-form").hide();
-        $("#op-add-edit").val('cud-add');
+        $("#op-add-edit").val("cud-add");
     });
 
-    $('#koha-sounds').on('change', function() {
+    $("#koha-sounds").on("change", function () {
         soundfield.val(this.value);
         enablePlayButton($(this).val(), playsound);
     });
 
-    playsound.on('click', function(e) {
+    playsound.on("click", function (e) {
         e.preventDefault();
-        if (soundfield.val() !== '') {
+        if (soundfield.val() !== "") {
             playSound(soundfield.val());
         } else {
             alert(__("Please select or enter a sound."));
         }
     });
 
-    $('#cancel-edit').on('click', function(e) {
+    $("#cancel-edit").on("click", function (e) {
         e.preventDefault();
 
         enablePlayButton("", playsound);
@@ -68,19 +68,21 @@ $(document).ready(function() {
         $(".create-alert").show();
         $("#new-alert-form").hide();
         $("#delete-alert-form").show();
-        $("#op-add-edit").val('cud-add');
+        $("#op-add-edit").val("cud-add");
     });
 
-    $('#delete-alert-form').on('submit', function() {
+    $("#delete-alert-form").on("submit", function () {
         if (checkedcheckboxes == 1) {
-            return confirm(__("Are you sure you want to delete the selected audio alerts?"));
+            return confirm(
+                __("Are you sure you want to delete the selected audio alerts?")
+            );
         } else {
             alert(__("Check the box next to the alert you want to delete."));
             return false;
         }
     });
 
-    $(".edit").on("click", function(e) {
+    $(".edit").on("click", function (e) {
         e.preventDefault();
         var elt = this;
         var id = $(this).data("soundid");
@@ -92,7 +94,7 @@ $(document).ready(function() {
 });
 
 function enablePlayButton(sound_field_value, playbutton) {
-    if (sound_field_value !== '') {
+    if (sound_field_value !== "") {
         playbutton.removeClass("disabled");
     } else {
         playbutton.addClass("disabled");
@@ -100,7 +102,7 @@ function enablePlayButton(sound_field_value, playbutton) {
 }
 
 function EditAlert(elt, id, precedence, selector, sound) {
-    $("#op-add-edit").val('cud-edit');
+    $("#op-add-edit").val("cud-edit");
     $("#new-alert-form").show();
     $("#delete-alert-form").hide();
     $("#toolbar").hide();
@@ -110,5 +112,5 @@ function EditAlert(elt, id, precedence, selector, sound) {
     $("#selector").val(selector);
     $("#sound").val(sound);
     $("#koha-sounds").val(sound);
-    enablePlayButton(sound, $('#play-sound'));
+    enablePlayButton(sound, $("#play-sound"));
 }
