@@ -555,8 +555,14 @@ function _dt_default_ajax(params) {
                                 const search_value = value.length
                                     ? value
                                     : global_search;
+
+                                // Escape all regex metachars . * + ? ^ $ { } ( ) | [ ] \
                                 const regex = new RegExp(
-                                    `^${search_value}`,
+                                    "^" +
+                                        search_value.replace(
+                                            /[.*+?^${}()|[\]\\]/g,
+                                            "\\$&"
+                                        ),
                                     "i"
                                 );
                                 if (
@@ -950,6 +956,40 @@ function _dt_buttons(params) {
     return buttons;
 }
 
+function _dt_force_visibility(table_settings, table_dt, state) {
+    var columns_settings = table_settings.columns;
+    let i = 0;
+    let force_vis_columns = table_settings.columns.filter(
+        c => c.force_visibility
+    );
+    if (!force_vis_columns.length) return state;
+
+    let use_names = $(table_dt.table().node()).data("bKohaColumnsUseNames");
+    if (use_names) {
+        table_dt
+            .columns(
+                force_vis_columns
+                    .map(c => "[data-colname='%s']".format(c.columnname))
+                    .join(",")
+            )
+            .every(function () {
+                state.columns[this.index()].visible =
+                    table_settings.columns.find(
+                        c =>
+                            c.columnname ==
+                            this.header().getAttribute("data-colname")
+                    ).is_hidden
+                        ? false
+                        : true;
+            });
+    } else {
+        throw new Error(
+            "Cannot force column visibility without bKohaColumnsUseNames!"
+        );
+    }
+    return state;
+}
+
 function _dt_visibility(table_settings, table_dt) {
     let hidden_ids = [];
     if (table_settings) {
@@ -1183,6 +1223,9 @@ function _dt_save_restore_state(table_settings, external_filter_nodes = {}) {
             delete state.search;
             state.columns.forEach(c => delete c.search);
         }
+
+        state = _dt_force_visibility(table_settings, this.api(), state);
+
         return state;
     };
 
@@ -1373,8 +1416,8 @@ function update_search_description(
             if (options.ajax && !options.bKohaAjaxSVC) {
                 options.ajax = Object.assign(
                     {},
-                    options.ajax,
-                    _dt_default_ajax({ default_filters, options })
+                    _dt_default_ajax({ default_filters, options }),
+                    options.ajax
                 );
                 options.serverSide = true;
                 options.processing = true;
