@@ -1,7 +1,7 @@
-/* global KohaTable allColumns Cookies */
+/* global kohaTable allColumns Cookies */
 // Set expiration date for cookies
 var date = new Date();
-date.setTime(date.getTime() + (365 * 24 * 60 * 60 * 1000));
+date.setTime(date.getTime() + 365 * 24 * 60 * 60 * 1000);
 
 function guess_nb_cols() {
     // This is a bit ugly, we are trying to know if there are checkboxes in the first column of the table
@@ -21,30 +21,46 @@ function hideColumns() {
         valCookie = valCookie.split("/");
         $("#showall").prop("checked", false).parent().removeClass("selected");
         $("#hideall").prop("checked", true).parent().addClass("selected");
-        for ( var i = 0; i < valCookie.length; i++ ) {
-            if (valCookie[i] !== '') {
+        for (var i = 0; i < valCookie.length; i++) {
+            if (valCookie[i] !== "") {
                 var index = valCookie[i] - nb_cols;
-                $("#itemst td:nth-child(" + valCookie[i] + "),#itemst th:nth-child(" + valCookie[i] + ")").toggle();
-                $("#checkheader" + index).prop("checked", false).parent().removeClass("selected");
+                $(
+                    "#itemst td:nth-child(" +
+                        valCookie[i] +
+                        "),#itemst th:nth-child(" +
+                        valCookie[i] +
+                        ")"
+                ).toggle();
+                $("#checkheader" + index)
+                    .prop("checked", false)
+                    .parent()
+                    .removeClass("selected");
             }
         }
     }
 }
 
 function hideColumn(num) {
-    $("#hideall,#showall").prop("checked", false).parent().removeClass("selected");
+    $("#hideall,#showall")
+        .prop("checked", false)
+        .parent()
+        .removeClass("selected");
     var nb_cols = guess_nb_cols();
     var valCookie = Cookies.get("showColumns");
     // set the index of the table column to hide
-    $("#" + num).parent().removeClass("selected");
+    $("#" + num)
+        .parent()
+        .removeClass("selected");
     var hide = Number(num.replace("checkheader", "")) + nb_cols;
     // hide header and cells matching the index
-    $("#itemst td:nth-child(" + hide + "),#itemst th:nth-child(" + hide + ")").toggle();
+    $(
+        "#itemst td:nth-child(" + hide + "),#itemst th:nth-child(" + hide + ")"
+    ).toggle();
     // set or modify cookie with the hidden column's index
     if (valCookie) {
         valCookie = valCookie.split("/");
         var found = false;
-        for ( var i = 0; i < valCookie.length; i++ ) {
+        for (var i = 0; i < valCookie.length; i++) {
             if (hide == valCookie[i]) {
                 found = true;
                 break;
@@ -53,10 +69,18 @@ function hideColumn(num) {
         if (!found) {
             valCookie.push(hide);
             var cookieString = valCookie.join("/");
-            Cookies.set("showColumns", cookieString, { expires: date, path: '/', sameSite: 'Lax'  });
+            Cookies.set("showColumns", cookieString, {
+                expires: date,
+                path: "/",
+                sameSite: "Lax",
+            });
         }
     } else {
-        Cookies.set("showColumns", hide, { expires: date, path: '/', sameSite: 'Lax'  });
+        Cookies.set("showColumns", hide, {
+            expires: date,
+            path: "/",
+            sameSite: "Lax",
+        });
     }
 }
 
@@ -70,18 +94,22 @@ Array.prototype.remove = function (from, to) {
 
 function showColumn(num) {
     $("#hideall").prop("checked", false).parent().removeClass("selected");
-    $("#" + num).parent().addClass("selected");
+    $("#" + num)
+        .parent()
+        .addClass("selected");
     var valCookie = Cookies.get("showColumns");
     // set the index of the table column to hide
     var nb_cols = guess_nb_cols();
     var show = Number(num.replace("checkheader", "")) + nb_cols;
     // hide header and cells matching the index
-    $("#itemst td:nth-child(" + show + "),#itemst th:nth-child(" + show + ")").toggle();
+    $(
+        "#itemst td:nth-child(" + show + "),#itemst th:nth-child(" + show + ")"
+    ).toggle();
     // set or modify cookie with the hidden column's index
     if (valCookie) {
         valCookie = valCookie.split("/");
         var found = false;
-        for ( var i = 0; i < valCookie.length; i++ ) {
+        for (var i = 0; i < valCookie.length; i++) {
             if (show == valCookie[i]) {
                 valCookie.remove(i);
                 found = true;
@@ -89,7 +117,11 @@ function showColumn(num) {
         }
         if (found) {
             var cookieString = valCookie.join("/");
-            Cookies.set("showColumns", cookieString, { expires: date, path: '/', sameSite: 'Lax'  });
+            Cookies.set("showColumns", cookieString, {
+                expires: date,
+                path: "/",
+                sameSite: "Lax",
+            });
         }
     }
 }
@@ -100,8 +132,16 @@ function showAllColumns() {
         $(this).prop("checked", true);
     });
     $("#selections span").addClass("selected");
-    $("#itemst td:nth-child("+nb_cols+"),#itemst tr th:nth-child("+nb_cols+")").nextAll().show();
-    Cookies.remove("showColumns", { path: '/' });
+    $(
+        "#itemst td:nth-child(" +
+            nb_cols +
+            "),#itemst tr th:nth-child(" +
+            nb_cols +
+            ")"
+    )
+        .nextAll()
+        .show();
+    Cookies.remove("showColumns", { path: "/" });
     $("#hideall").prop("checked", false).parent().removeClass("selected");
 }
 
@@ -111,26 +151,42 @@ function hideAllColumns() {
         $(this).prop("checked", false);
     });
     $("#selections span").removeClass("selected");
-    $("#itemst td:nth-child("+nb_cols+"),#itemst tr th:nth-child("+nb_cols+")").nextAll().hide();
+    $(
+        "#itemst td:nth-child(" +
+            nb_cols +
+            "),#itemst tr th:nth-child(" +
+            nb_cols +
+            ")"
+    )
+        .nextAll()
+        .hide();
     $("#hideall").prop("checked", true).parent().addClass("selected");
     var cookieString = allColumns.join("/");
-    Cookies.set("showColumns", cookieString, { expires: date, path: '/', sameSite: 'Lax'  });
+    Cookies.set("showColumns", cookieString, {
+        expires: date,
+        path: "/",
+        sameSite: "Lax",
+    });
+}
+
+function ShowSerialEditingConfirmation(form) {
+    $("#edit-serial-issues-modal").modal("show");
+    return false;
 }
 
 $(document).ready(function () {
-    var items_table = KohaTable("itemst", {
-        "columnDefs":  [
-            { "targets":  [0, 1], "orderable":  false, "searchable":  true },
-            { "targets":  [0], "visible":  false },
-            { "type":  "anti-the", "targets":  ["anti-the"] }
+    var items_table = $("#itemst").kohaTable({
+        columnDefs: [
+            { targets: [0, 1], orderable: false, searchable: true },
+            { targets: [0], visible: false },
         ],
-        "paging":  false,
+        paging: false,
     });
 
     hideColumns();
 
     // Highlight in yellow item rows that cannot be deleted
-    $(".error").parents('tr').find('td').css('background-color', '#ffff99');
+    $(".error").parents("tr").find("td").css("background-color", "#ffff99");
 
     $("#selectallbutton").click(function (e) {
         e.preventDefault();
@@ -145,17 +201,19 @@ $(document).ready(function () {
         });
     });
     $("#clearonloanbutton").click(function () {
-        $("#itemst input[name='itemnumber'][data-is-onloan='1']").each(function () {
-            $(this).prop('checked', false);
-        });
+        $("#itemst input[name='itemnumber'][data-is-onloan='1']").each(
+            function () {
+                $(this).prop("checked", false);
+            }
+        );
         return false;
     });
     $("#selections input").change(function (e) {
         var num = $(this).attr("id");
-        if (num == 'showall') {
+        if (num == "showall") {
             showAllColumns();
             e.stopPropagation();
-        } else if (num == 'hideall') {
+        } else if (num == "hideall") {
             hideAllColumns();
             e.stopPropagation();
         } else {
@@ -166,4 +224,23 @@ $(document).ready(function () {
             }
         }
     });
+    $(document).on(
+        "click",
+        "#edit-serial-issues-modal-btn-submit",
+        function (e) {
+            e.preventDefault();
+            $("#edit-serial-issues-modal").modal("hide");
+            $("#edit-serial-issues").val("1");
+            return $("form[name='f'").submit();
+        }
+    );
+    $(document).on(
+        "click",
+        "#no-edit-serial-issues-modal-btn-submit",
+        function (e) {
+            e.preventDefault();
+            $("#edit-serial-issues-modal").modal("hide");
+            return $("form[name='f'").submit();
+        }
+    );
 });
