@@ -24,25 +24,26 @@ use C4::Auth qw( checkauth );
 my $cgi = CGI->new;
 
 my $authnotrequired = 0;
-my $flags = {
+my $flags           = {
     borrowers     => 'edit_borrowers',
     updatecharges => 'remaining_permissions'
 };
 
 my $type = 'intranet';
-my ($user, $cookie) = C4::Auth::checkauth($cgi, $authnotrequired, $flags, $type);
+my ( $user, $cookie ) = C4::Auth::checkauth( $cgi, $authnotrequired, $flags, $type );
 
 my $op = $cgi->param('op') // q{};
 
 if ( $op eq "cud-cancel" ) {
-    my $accountlines_id = $cgi->param('accountlines_id');
-
-    my $charge         = Koha::Account::Lines->find($accountlines_id);
-    my $borrowernumber = $charge->patron->borrowernumber;
+    my $accountlines_id    = $cgi->param('accountlines_id');
+    my $cancel_charge_note = $cgi->param('cancel_charge_note');
+    my $charge             = Koha::Account::Lines->find($accountlines_id);
+    my $borrowernumber     = $charge->patron->borrowernumber;
     $charge->cancel(
         {
             branch   => C4::Context->userenv->{'branch'},
-            staff_id => C4::Context->userenv->{'number'}
+            staff_id => C4::Context->userenv->{'number'},
+            note     => $cancel_charge_note,
         }
     );
     print $cgi->redirect( '/cgi-bin/koha/members/boraccount.pl?borrowernumber=' . $borrowernumber );
