@@ -22,8 +22,8 @@ use Modern::Perl;
 use CGI;
 
 use C4::Context;
-use C4::Auth qw( get_template_and_user );
-use C4::Output qw( output_and_exit_if_error output_and_exit output_html_with_http_headers );
+use C4::Auth     qw( get_template_and_user );
+use C4::Output   qw( output_and_exit_if_error output_and_exit output_html_with_http_headers );
 use C4::Overdues qw( parse_overdues_letter );
 
 use Koha::Patrons;
@@ -34,23 +34,24 @@ my $flagsrequired = { circulate => "circulate_remaining_permissions" };
 
 my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "circ/printslip.tt",
-        query           => $input,
-        type            => "intranet",
-        flagsrequired   => $flagsrequired,
+        template_name => "circ/printslip.tt",
+        query         => $input,
+        type          => "intranet",
+        flagsrequired => $flagsrequired,
     }
 );
 
 my $borrowernumber = $input->param('borrowernumber');
 my $branchcode     = C4::Context->userenv->{'branch'};
 
-my $logged_in_user = Koha::Patrons->find( $loggedinuser );
-my $patron         = Koha::Patrons->find( $borrowernumber );
-output_and_exit_if_error( $input, $cookie, $template, { module => 'members', logged_in_user => $logged_in_user, current_patron => $patron } );
+my $logged_in_user = Koha::Patrons->find($loggedinuser);
+my $patron         = Koha::Patrons->find($borrowernumber);
+output_and_exit_if_error(
+    $input, $cookie, $template,
+    { module => 'members', logged_in_user => $logged_in_user, current_patron => $patron }
+);
 
-my $overdues = [
-    map { $_->unblessed_all_relateds } $patron->overdues->as_list
-];
+my $overdues = [ map { $_->unblessed_all_relateds } $patron->overdues->as_list ];
 
 my $letter = parse_overdues_letter(
     {
