@@ -236,7 +236,7 @@ if ($delete) {
         $dbh->do("ALTER TABLE items AUTO_INCREMENT = 1");
     } else {
         print "Deleting authorities\n";
-        $dbh->do("DELETE FROM auth_header");
+        $dbh->do("truncate auth_header");
     }
     $dbh->do("truncate zebraqueue");
 }
@@ -360,6 +360,7 @@ RECORD: while () {
                 next;
             }
         }
+
         # transcode the record to UTF8 if needed & applicable.
         if ( $record->encoding() eq 'MARC-8' and not $skip_marc8_conversion ) {
             my ( $guessed_charset, $charset_errors );
