@@ -20,29 +20,31 @@
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
-use C4::Auth qw( get_template_and_user );
+use CGI             qw ( -utf8 );
+use C4::Auth        qw( get_template_and_user );
 use C4::Circulation qw( GetOfflineOperation ProcessOfflineOperation DeleteOfflineOperation );
 
 my $query = CGI->new;
 
-my ($template, $loggedinuser, $cookie) = get_template_and_user({
-    template_name => "offline_circ/list.tt",
-    query => $query,
-    type => "intranet",
-    flagsrequired   => { circulate => "circulate_remaining_permissions" },
-});
+my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
+    {
+        template_name => "offline_circ/list.tt",
+        query         => $query,
+        type          => "intranet",
+        flagsrequired => { circulate => "circulate_remaining_permissions" },
+    }
+);
 
 my $operationid = $query->param('operationid');
-my $op = $query->param('op') || q{};
+my $op          = $query->param('op') || q{};
 my $result;
 
 if ( $op eq 'cud-process' ) {
-    my $operation = GetOfflineOperation( $operationid );
-    $result = ProcessOfflineOperation( $operation );
+    my $operation = GetOfflineOperation($operationid);
+    $result = ProcessOfflineOperation($operation);
 } elsif ( $op eq 'cud-delete' ) {
-    $result = DeleteOfflineOperation( $operationid );
+    $result = DeleteOfflineOperation($operationid);
 }
 
-print CGI::header('-type'=>'text/plain', '-charset'=>'utf-8');
+print CGI::header( '-type' => 'text/plain', '-charset' => 'utf-8' );
 print $result;
