@@ -17,9 +17,9 @@
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
-use C4::Auth qw( get_template_and_user );
-use C4::Output qw( output_html_with_http_headers );
+use CGI           qw ( -utf8 );
+use C4::Auth      qw( get_template_and_user );
+use C4::Output    qw( output_html_with_http_headers );
 use C4::Languages qw( getlanguage );
 use Koha::AdditionalContents;
 
@@ -37,13 +37,17 @@ my ( $template, $borrowernumber, $cookie ) = get_template_and_user(
 my $page_id = $query->param('page_id');
 
 my $homebranch = $ENV{OPAC_BRANCH_DEFAULT};
-if (C4::Context->userenv) {
+if ( C4::Context->userenv ) {
     $homebranch = C4::Context->userenv->{'branch'};
 }
 
 my $page = Koha::AdditionalContents->find($page_id);
 
-if ( !$page || $page->category ne 'pages' || $page->branchcode && $page->branchcode != $homebranch || $page->location ne 'opac_only' && $page->location ne 'staff_and_opac' ) {
+if (  !$page
+    || $page->category ne 'pages'
+    || $page->branchcode && $page->branchcode != $homebranch
+    || $page->location ne 'opac_only' && $page->location ne 'staff_and_opac' )
+{
     print $query->redirect('/cgi-bin/koha/errors/404.pl');
     exit;
 }
