@@ -22,6 +22,7 @@ use CGI qw ( -utf8 );
 use C4::Auth        qw( get_template_and_user );
 use C4::Circulation qw( AddReturn );
 use C4::Output      qw( output_html_with_http_headers );
+use Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue;
 use Koha::Items;
 
 use List::MoreUtils qw( uniq );
@@ -86,6 +87,11 @@ if ( $op eq 'cud-check_in' ) {
                     checkout => $checkout,
                     patron   => $patron
                     };
+
+                # Rebuild holds queue on checkin
+                Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue->new->enqueue(
+                    { biblio_ids => [ $item->biblionumber ] } )
+                    if C4::Context->preference('RealTimeHoldsQueue');
             } else {
                 push @errors,
                     {
