@@ -24,9 +24,9 @@ use CGI;
 use List::MoreUtils qw( uniq );
 use Try::Tiny;
 
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_html_with_http_headers );
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Biblio;
 use C4::AuthoritiesMarc;
 use Koha::Acquisition::Orders;
@@ -39,23 +39,26 @@ use Koha::BackgroundJob::BatchDeleteBiblio;
 use Koha::BackgroundJob::BatchDeleteAuthority;
 
 my $input            = CGI->new;
-my $op               = $input->param('op') // q|form|;
-my $recordtype       = $input->param('recordtype') // 'biblio';
+my $op               = $input->param('op')               // q|form|;
+my $recordtype       = $input->param('recordtype')       // 'biblio';
 my $skip_open_orders = $input->param('skip_open_orders') // 0;
 
-my ($template, $loggedinuser, $cookie) = get_template_and_user({
+my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
+    {
         template_name => 'tools/batch_delete_records.tt',
-        query => $input,
-        type => "intranet",
+        query         => $input,
+        type          => "intranet",
         flagsrequired => { tools => 'records_batchdel' },
-});
+    }
+);
 
 my @records;
 my @messages;
 if ( $op eq 'form' ) {
+
     # Display the form
     $template->param(
-        op => 'form',
+        op    => 'form',
         lists => Koha::Virtualshelves->search(
             [
                 { public => 0, owner => $loggedinuser },
@@ -64,13 +67,16 @@ if ( $op eq 'form' ) {
         )
     );
 } elsif ( $op eq 'cud-list' ) {
+
     # List all records to process
     my @record_ids;
     if ( my $bib_list = $input->param('bib_list') ) {
+
         # Come from the basket
         @record_ids = split /\//, $bib_list;
         $recordtype = 'biblio';
     } elsif ( my $uploadfile = $input->param('uploadfile') ) {
+
         # A file of id is given
         binmode $uploadfile, ':encoding(UTF-8)';
         while ( my $content = <$uploadfile> ) {
@@ -79,34 +85,37 @@ if ( $op eq 'form' ) {
             push @record_ids, $content if $content;
         }
     } elsif ( my $shelf_number = $input->param('shelf_number') ) {
-        my $shelf = Koha::Virtualshelves->find($shelf_number);
+        my $shelf    = Koha::Virtualshelves->find($shelf_number);
         my $contents = $shelf->get_contents;
         while ( my $content = $contents->next ) {
             my $biblionumber = $content->biblionumber;
             push @record_ids, $biblionumber;
         }
     } else {
+
         # The user enters manually the list of id
         push @record_ids, split( /\s\n/, scalar $input->param('recordnumber_list') );
     }
 
     for my $record_id ( uniq @record_ids ) {
         if ( $recordtype eq 'biblio' ) {
+
             # Retrieve biblio information
-            my $biblio_object = Koha::Biblios->find( $record_id );
-            unless ( $biblio_object ) {
+            my $biblio_object = Koha::Biblios->find($record_id);
+            unless ($biblio_object) {
                 push @messages, {
-                    type => 'warning',
-                    code => 'biblio_not_exists',
+                    type         => 'warning',
+                    code         => 'biblio_not_exists',
                     biblionumber => $record_id,
                 };
                 next;
             }
             my $biblio = $biblio_object->unblessed;
             my $record = $biblio_object->metadata->record;
-            $biblio->{itemnumbers} = [Koha::Items->search({ biblionumber => $record_id })->get_column('itemnumber')];
-            $biblio->{holds_count} = $biblio_object->holds->count;
-            $biblio->{issues_count} = C4::Biblio::CountItemsIssued( $record_id );
+            $biblio->{itemnumbers} =
+                [ Koha::Items->search( { biblionumber => $record_id } )->get_column('itemnumber') ];
+            $biblio->{holds_count}         = $biblio_object->holds->count;
+            $biblio->{issues_count}        = C4::Biblio::CountItemsIssued($record_id);
             $biblio->{subscriptions_count} = $biblio_object->subscriptions->count;
 
             # Respect skip_open_orders
@@ -117,51 +126,53 @@ if ( $op eq 'form' ) {
 
             push @records, $biblio;
         } else {
+
             # Retrieve authority information
-            my $authority = C4::AuthoritiesMarc::GetAuthority( $record_id );
-            unless ( $authority ) {
+            my $authority = C4::AuthoritiesMarc::GetAuthority($record_id);
+            unless ($authority) {
                 push @messages, {
-                    type => 'warning',
-                    code => 'authority_not_exists',
+                    type   => 'warning',
+                    code   => 'authority_not_exists',
                     authid => $record_id,
                 };
                 next;
             }
 
             $authority = {
-                authid => $record_id,
-                summary => C4::AuthoritiesMarc::BuildSummary( $authority, $record_id ),
-                count_usage => Koha::Authorities->get_usage_count({ authid => $record_id }),
+                authid      => $record_id,
+                summary     => C4::AuthoritiesMarc::BuildSummary( $authority, $record_id ),
+                count_usage => Koha::Authorities->get_usage_count( { authid => $record_id } ),
             };
             push @records, $authority;
         }
     }
     $template->param(
         records => \@records,
-        op => 'list',
+        op      => 'list',
     );
 } elsif ( $op eq 'cud-delete' ) {
+
     # We want to delete selected records!
     my @record_ids = $input->multi_param('record_id');
 
     try {
         my $params = {
-            record_ids  => \@record_ids,
+            record_ids => \@record_ids,
         };
 
         my $job_id =
-          $recordtype eq 'biblio'
-          ? Koha::BackgroundJob::BatchDeleteBiblio->new->enqueue($params)
-          : Koha::BackgroundJob::BatchDeleteAuthority->new->enqueue($params);
+            $recordtype eq 'biblio'
+            ? Koha::BackgroundJob::BatchDeleteBiblio->new->enqueue($params)
+            : Koha::BackgroundJob::BatchDeleteAuthority->new->enqueue($params);
 
         $template->param(
-            op => 'enqueued',
+            op     => 'enqueued',
             job_id => $job_id,
         );
     } catch {
         push @messages, {
-            type => 'error',
-            code => 'cannot_enqueue_job',
+            type  => 'error',
+            code  => 'cannot_enqueue_job',
             error => $_,
         };
         $template->param( view => 'errors' );
@@ -169,7 +180,7 @@ if ( $op eq 'form' ) {
 }
 
 $template->param(
-    messages => \@messages,
+    messages   => \@messages,
     recordtype => $recordtype,
 );
 
